tx

package
v4.0.0-...-ec2720d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: Apache-2.0 Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidLengthService        = fmt.Errorf("proto: negative length found during unmarshaling")
	ErrIntOverflowService          = fmt.Errorf("proto: integer overflow")
	ErrUnexpectedEndOfGroupService = fmt.Errorf("proto: unexpected end of group")
)

Functions

func RegisterServiceServer

func RegisterServiceServer(s grpc1.Server, srv ServiceServer)

func RegisterTxService

func RegisterTxService(
	server grpc1.Server,
)

Types

type ComputeTaxRequest

type ComputeTaxRequest struct {
	// tx is the transaction to simulate.
	// Deprecated. Send raw tx bytes instead.
	Tx *tx.Tx `protobuf:"bytes,1,opt,name=tx,proto3" json:"tx,omitempty"` // Deprecated: Do not use.
	// tx_bytes is the raw transaction.
	TxBytes []byte `protobuf:"bytes,2,opt,name=tx_bytes,json=txBytes,proto3" json:"tx_bytes,omitempty"`
}

ComputeTaxRequest is the request type for the Service.ComputeTax RPC method.

func (*ComputeTaxRequest) Descriptor

func (*ComputeTaxRequest) Descriptor() ([]byte, []int)

func (*ComputeTaxRequest) GetTx deprecated

func (m *ComputeTaxRequest) GetTx() *tx.Tx

Deprecated: Do not use.

func (*ComputeTaxRequest) GetTxBytes

func (m *ComputeTaxRequest) GetTxBytes() []byte

func (*ComputeTaxRequest) Marshal

func (m *ComputeTaxRequest) Marshal() (dAtA []byte, err error)

func (*ComputeTaxRequest) MarshalTo

func (m *ComputeTaxRequest) MarshalTo(dAtA []byte) (int, error)

func (*ComputeTaxRequest) MarshalToSizedBuffer

func (m *ComputeTaxRequest) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*ComputeTaxRequest) ProtoMessage

func (*ComputeTaxRequest) ProtoMessage()

func (*ComputeTaxRequest) Reset

func (m *ComputeTaxRequest) Reset()

func (*ComputeTaxRequest) Size

func (m *ComputeTaxRequest) Size() (n int)

func (*ComputeTaxRequest) String

func (m *ComputeTaxRequest) String() string

func (*ComputeTaxRequest) Unmarshal

func (m *ComputeTaxRequest) Unmarshal(dAtA []byte) error

func (*ComputeTaxRequest) XXX_DiscardUnknown

func (m *ComputeTaxRequest) XXX_DiscardUnknown()

func (*ComputeTaxRequest) XXX_Marshal

func (m *ComputeTaxRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ComputeTaxRequest) XXX_Merge

func (m *ComputeTaxRequest) XXX_Merge(src proto.Message)

func (*ComputeTaxRequest) XXX_Size

func (m *ComputeTaxRequest) XXX_Size() int

func (*ComputeTaxRequest) XXX_Unmarshal

func (m *ComputeTaxRequest) XXX_Unmarshal(b []byte) error

type ComputeTaxResponse

type ComputeTaxResponse struct {
	// amount is the amount of coins to be paid as a fee
	TaxAmount github_com_cosmos_cosmos_sdk_types.Coins `` /* 132-byte string literal not displayed */
}

ComputeTaxResponse is the response type for the Service.ComputeTax RPC method.

func (*ComputeTaxResponse) Descriptor

func (*ComputeTaxResponse) Descriptor() ([]byte, []int)

func (*ComputeTaxResponse) GetTaxAmount

func (*ComputeTaxResponse) Marshal

func (m *ComputeTaxResponse) Marshal() (dAtA []byte, err error)

func (*ComputeTaxResponse) MarshalTo

func (m *ComputeTaxResponse) MarshalTo(dAtA []byte) (int, error)

func (*ComputeTaxResponse) MarshalToSizedBuffer

func (m *ComputeTaxResponse) MarshalToSizedBuffer(dAtA []byte) (int, error)

func (*ComputeTaxResponse) ProtoMessage

func (*ComputeTaxResponse) ProtoMessage()

func (*ComputeTaxResponse) Reset

func (m *ComputeTaxResponse) Reset()

func (*ComputeTaxResponse) Size

func (m *ComputeTaxResponse) Size() (n int)

func (*ComputeTaxResponse) String

func (m *ComputeTaxResponse) String() string

func (*ComputeTaxResponse) Unmarshal

func (m *ComputeTaxResponse) Unmarshal(dAtA []byte) error

func (*ComputeTaxResponse) XXX_DiscardUnknown

func (m *ComputeTaxResponse) XXX_DiscardUnknown()

func (*ComputeTaxResponse) XXX_Marshal

func (m *ComputeTaxResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)

func (*ComputeTaxResponse) XXX_Merge

func (m *ComputeTaxResponse) XXX_Merge(src proto.Message)

func (*ComputeTaxResponse) XXX_Size

func (m *ComputeTaxResponse) XXX_Size() int

func (*ComputeTaxResponse) XXX_Unmarshal

func (m *ComputeTaxResponse) XXX_Unmarshal(b []byte) error

type ServiceClient

type ServiceClient interface {
	// EstimateFee simulates executing a transaction for estimating gas usage.
	ComputeTax(ctx context.Context, in *ComputeTaxRequest, opts ...grpc.CallOption) (*ComputeTaxResponse, error)
}

ServiceClient is the client API for Service service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.

func NewServiceClient

func NewServiceClient(cc grpc1.ClientConn) ServiceClient

type ServiceServer

type ServiceServer interface {
	// EstimateFee simulates executing a transaction for estimating gas usage.
	ComputeTax(context.Context, *ComputeTaxRequest) (*ComputeTaxResponse, error)
}

ServiceServer is the server API for Service service.

type TreasuryService

type TreasuryService struct{}

func NewTreasuryService

func NewTreasuryService() TreasuryService

func (TreasuryService) ComputeTax

func (ts TreasuryService) ComputeTax(
	goCtx context.Context,
	req *ComputeTaxRequest,
) (*ComputeTaxResponse, error)

type UnimplementedServiceServer

type UnimplementedServiceServer struct {
}

UnimplementedServiceServer can be embedded to have forward compatible implementations.

func (*UnimplementedServiceServer) ComputeTax

Jump to